Why Dead-Hosts?
---------------

We are conscient that PyFunceble may run for days. We would therefore offer 
you, to have your list. `Request for Dead-Hosts`_ testing.

.. _Request for Dead-Hosts: https://github.com/dead-hosts/dev-center/issues/new?template=inclusion-request.md
